import React from 'react'
import { get } from 'lodash'
import { DateParser } from '@pubsweet/ui'
import { compose, withHandlers } from 'recompose'

import {
  Row,
  Item,
  Text,
  ActionLink,
  IconButton,
  PreviewFile,
  DownloadZipFiles,
  ManuscriptVersion,
} from 'pubsweet-component-faraday-ui'

const ManuscriptDetailsTop = ({
  history,
  goToEdit,
  getSignedUrl,
  canEditManuscript,
  goToTechnicalCheck,
  canOverrideTechChecks,
  fragment = {},
  collection = {},
  currentUser: { isReviewer, token },
}) => (
  <Row alignItems="center" mb={1}>
    <Item alignItems="center" justify="flex-start">
      <ActionLink icon="arrow-left" onClick={() => history.push('/dashboard')}>
        Dashboard
      </ActionLink>
    </Item>
    <Item alignItems="center" justify="flex-end">
      {canOverrideTechChecks && (
        <ActionLink
          data-test-id={`button-qa-manuscript-${fragment.id}`}
          icon="check-square"
          onClick={goToTechnicalCheck(collection)}
          pr={2}
        >
          Technical Checks
        </ActionLink>
      )}
      {canEditManuscript && (
        <ActionLink
          data-test-id={`button-qa-manuscript-${fragment.id}`}
          icon="edit"
          onClick={goToEdit(collection, fragment)}
          pr={2}
        >
          Edit
        </ActionLink>
      )}
      <PreviewFile
        file={get(fragment, 'files.manuscripts[0]', {})}
        getSignedUrl={getSignedUrl}
      />
      <DownloadZipFiles
        archiveName={`ID-${collection.customId}`}
        collectionId={collection.id}
        fragmentId={fragment.id}
        isReviewer={isReviewer}
        token={token}
      >
        <IconButton icon="download" iconSize={2} mr={3} secondary />
      </DownloadZipFiles>
      <DateParser durationThreshold={0} timestamp={fragment.submitted || ''}>
        {timestamp => (
          <Text mr={1} whiteSpace="nowrap">
            Updated on {timestamp}
          </Text>
        )}
      </DateParser>
      <ManuscriptVersion
        collection={collection}
        fragment={fragment}
        history={history}
      />
    </Item>
  </Row>
)

export default compose(
  withHandlers({
    goToEdit: ({ history }) => (collection, fragment) => () => {
      history.push(
        `/projects/${collection.id}/versions/${fragment.id}/submit`,
        {
          editMode: true,
        },
      )
    },
    goToTechnicalCheck: ({ history }) => collection => () => {
      const {
        status,
        id,
        customId,
        technicalChecks: { token = '' },
      } = collection
      const stage = status === 'technicalChecks' ? 'eqs' : 'eqa'
      history.push({
        pathname: `/${stage}-decision`,
        search: `?collectionId=${id}&customId=${customId}&token=${token}`,
      })
    },
  }),
)(ManuscriptDetailsTop)
